@@ -4,20 +4,24 @@
 #'
 #' @description This function implements the eigenvector-based semiparametric
 #' spatial filtering approach in a linear regression framework using ordinary least
-#' squares (OLS). Eigenvectors are selected by an unsupervised stepwise regression
-#' technique. Supported selection criteria are the minimization of residual
-#' autocorrelation, maximization of model fit, significance of residual autocorrelation,
-#' and the statistical significance of eigenvectors. Alternatively, all eigenvectors in
+#' squares (OLS). Eigenvectors are selected either by an unsupervised stepwise
+#' regression procedure or by a penalized regression approach. The stepwise procedure
+#' supports selection criteria based on the minimization of residual autocorrelation,
+#' maximization of model fit, significance of residual autocorrelation, and the
+#' statistical significance of eigenvectors. Alternatively, all eigenvectors in
 #' the candidate set can be included as well.
 #'
 #' @param y response variable
 #' @param x vector/ matrix of regressors (default = NULL)
 #' @param W spatial connectivity matrix
-#' @param objfn the objective function to be used for eigenvector selection.
-#' Possible criteria are: the maximization of the adjusted R-squared ('R2'),
-#' minimization of residual autocorrelation ('MI'), significance level of
-#' candidate eigenvectors ('p'), significance of residual spatial
-#' autocorrelation ('pMI') or all eigenvectors in the candidate set ('all')
+#' @param objfn the objective function to be used for eigenvector selection. For
+#' stepwise selection, possible criteria are: the maximization of the adjusted
+#' R-squared ('R2'), minimization of different information criteria ('AIC', 'AICc',
+#' or 'BIC'), minimization of residual autocorrelation ('MI'), significance level
+#' of candidate eigenvectors ('p'), or significance of residual spatial autocorrelation
+#' ('pMI'). The lasso-based selection ('MI-lasso') implements the procedure
+#' suggested by Barde et al. (2025). Alternatively, all eigenvectors in the candidate
+#' set ('all') can be included as well which does not require any selection procedure.
 #' @param MX covariates used to construct the projection matrix (default = NULL) - see
 #' Details
 #' @param sig significance level to be used for eigenvector selection
@@ -30,6 +34,10 @@
 #' @param ideal.setsize if \code{positive = TRUE}, uses the formula proposed by
 #' Chun et al. (2016) to determine the ideal size of the candidate set
 #' (TRUE/ FALSE)
+#' @param conditional.se report standard errors of the regression coefficients
+#' associated with the covariates conditional on the selected eigenvectors using
+#' a partial regression framework (TRUE/ FALSE). Recommended if \code{objfn =
+#' 'MI-lasso'} (Barde et al. (2025)) - see Details
 #' @param alpha a value in (0,1] indicating the range of candidate eigenvectors
 #' according to their associated level of spatial autocorrelation, see e.g.,
 #' Griffith (2003)
@@ -53,6 +61,7 @@
 #' \item{\code{moran}}{residual autocorrelation in the initial and the
 #' filtered model}
 #' \item{\code{fit}}{adjusted R-squared of the initial and the filtered model}
+#' \item{\code{ICs}}{information criteria (AIC, AICc, and BIC) of the initial and the filtered model}
 #' \item{\code{residuals}}{initial and filtered model residuals}
 #' \item{\code{other}}{a list providing supplementary information:
 #' \describe{
@@ -67,6 +76,7 @@
 #' the stepwise regression procedure}
 #' \item{\code{bonferroni}}{TRUE/ FALSE: Bonferroni-adjusted significance level
 #' (if \code{objfn = 'p'})}
+#' \item{\code{conditional.se}}{TRUE/ FALSE: conditional standard errors used}
 #' \item{\code{siglevel}}{if \code{objfn = 'p'} or \code{objfn = 'pMI'}: actual
 #' (unadjusted/ adjusted) significance level}
 #' }
@@ -87,18 +97,30 @@
 #' projection matrix becomes \strong{M} = \strong{I} - \strong{11}'/*n*,
 #' where \strong{1} is a vector of ones and *n* represents the number of
 #' observations. Griffith and Tiefelsdorf (2007) show how the choice of the appropriate
-#' \strong{M} depends on the underlying process that generates the spatial
-#' dependence.
+#' \strong{M} depends on the underlying spatial process. For inference on regression
+#' coefficients when the DGP is unknown, Moran eigenvectors should be derived
+#' independently of the regressors (\code{MX = NULL}). Projecting \strong{W} onto the
+#' space orthogonal to \strong{X} may alter the estimand of the regression coefficients
+#' and is therefore not recommended for general inference.
 #'
 #' The Bonferroni correction is only possible if eigenvector selection is based on
 #' the significance level of the eigenvectors (\code{objfn = 'p'}). It is set to
 #' FALSE if eigenvectors are added to the model until the residuals exhibit no
 #' significant level of spatial autocorrelation (\code{objfn = 'pMI'}).
+#' 
+#' For inference on regression coefficients, Barde et al. (2025) compute standard
+#' errors using a partial regression framework (see also Chernozhukov et al. (2015)).
+#' Both the outcome and the covariates are residualized with respect to the selected
+#' eigenvectors, and the variance–covariance matrix is calculated from these
+#' residualized variables. This approach treats the selected eigenvectors as fixed
+#' regressors and provides valid post-selection inference when eigenvector selection
+#' is stable. When \code{objfn = "MI-lasso"}, conditional standard errors are therefore
+#' generally recommended for inference on regression coefficients.
 #'
 #' @examples
 #' data(fakedata)
 #' y <- fakedataset$x1
-#' X <- cbind(fakedataset$x2, fakedataset$x3, fakedataset$x4)
+#' X <- cbind(fakedataset$x2, fakedataset$x3)
 #'
 #' res <- lmFilter(y = y, x = X, W = W, objfn = 'MI', positive = FALSE)
 #' print(res)
@@ -129,6 +151,15 @@
 #' Tiefelsdorf, Michael and Barry Boots (1995): The Exact Distribution
 #' of Moran's I. Environment and Planning A: Economy and Space, 27 (6):
 #' pp. 985 - 999.
+#' 
+#' Barde, Sylvain, Rowan Cherodian, Guy Tchuente (2025): Moran’s I lasso
+#' for models with spatially correlated data. The Econometrics Journal,
+#' 28 (3): pp. 423 - 441.
+#' 
+#' Chernozhukov, Victor, Christian Hansen and Martin Spindler (2015):
+#' Post-selection and post-regularization inference in linear models with
+#' many controls and instruments. American Economic Review, 105 (5), pp.
+#' 486 - 490.
 #'
 #' @importFrom stats pt sd
 #'
@@ -138,7 +169,8 @@
 
 lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
                      bonferroni = TRUE, positive = TRUE, ideal.setsize = FALSE,
-                     alpha = .25, tol = .1, boot.MI = NULL, na.rm = TRUE) {
+                     conditional.se = FALSE, alpha = .25, tol = .1,
+                     boot.MI = NULL, na.rm = TRUE) {
 
   if (!is.null(MX)) {
     MX <- data.matrix(MX)
@@ -186,6 +218,9 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   #####
   # Input Checks
   #####
+  if (objfn == 'MI-lasso' & !conditional.se) {
+    warning("Note: Conditional standard errors are recommended for inference on regression coefficients when using MI-lasso")
+  }
   if (anyNA(y) | anyNA(x) | anyNA(W)) {
     stop("Missing values detected")
   }
@@ -204,8 +239,9 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   if (any(class(W) != "matrix")) {
     W <- as.matrix(W)
   }
-  if (!(objfn %in% c("R2", "p", "MI", "pMI", "all"))) {
-    stop("Invalid argument: objfn must be one of 'R2', 'p', 'MI', 'pMI', or'all'")
+  if (!(objfn %in% c("R2", "AIC", "AICc", "BIC", "p", "MI", "pMI", "MI-lasso", "all"))) {
+    stop("Invalid argument: objfn must be one of 'MI-lasso', 'R2', 'AIC', 'AICc'
+        ,'BIC', 'p', 'MI', 'pMI', or 'all'")
   }
   if (positive == FALSE & ideal.setsize == TRUE) {
     stop("Estimating the ideal set size is only valid for positive spatial autocorrelation")
@@ -225,6 +261,10 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
       TSS <- sum((y - mean(y))^2)
       R2 <- 1 - (sum(resid^2) / TSS)
       test <- -(1 - (1 - R2) * (n - 1) / (n - (ncol(xe))) ) # negative adjusted R-squared
+    } else if (objfn %in% c("AIC", "AICc", "BIC")) {
+      RSS <- sum(crossprod(resid))
+      negll <- 0.5 * n * (log(2 * pi) + 1 + log(RSS / n))
+      test <- getICs(negloglik = negll, n = n, df = ncol(xe))[objfn]
     } else if (objfn == "p") {
       est <- (solve(crossprod(xe)) %*% crossprod(xe, y))[ncol(xe),]
       se <- sqrt((solve(t(xe) %*% xe)[ncol(xe), ncol(xe)] * sum(resid^2)) / (nrow(W) - ncol(xe)))
@@ -257,8 +297,11 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   coefs_init <- solve(crossprod(x)) %*% crossprod(x, y)
   fitvals <- fittedval(x = x, params = coefs_init, model = "linear")
   resid_init <- residfun(y = y, fitvals = fitvals, model = "linear")$raw
-  R2 <- 1 - (sum(crossprod(resid_init)) / TSS)
+  RSS <- sum(crossprod(resid_init))
+  R2 <- 1 - (RSS / TSS)
   adjR2_init <- 1 - (1 - R2) * (n - 1) / (n - nx)
+  negll_init <- 0.5 * n * (log(2 * pi) + 1 + log(RSS / n))
+  ICs_init <- getICs(negloglik = negll_init, n = n, df = length(coefs_init))
   zMI_init <- MI.resid(resid = resid_init, x = x, W = W, boot = boot.MI)$zI
   if (objfn == "MI") {
     oldZMI <- abs(zMI_init)
@@ -266,6 +309,9 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   if (objfn == "R2") {
     adjR2 <- -adjR2_init
   }
+  if (objfn %in% c("AIC", "AICc", "BIC")) {
+    IC <- ICs_init[objfn]
+  }
 
   #####
   # Eigenvector Selection:
@@ -309,14 +355,17 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   # Search Algorithm:
   # Stepwise Regression
   #####
-  if (objfn == "all") {
+  selset <- which(sel)
+  if (objfn == "MI-lasso") {
+    sel_id <- MI_lasso(y = y, x = x, evecs = evecs, selset = selset, zMI = zMI_init
+                      ,n = n, maxit = 1000, tol = 1e-7)
+  } else if (objfn == "all") {
     sel_id <- which(sel)
   } else {
     sel_id <- NULL
-    selset <- which(sel)
 
     # start forward search
-    for (i in which(sel)) {
+    for (i in selset) {
       if (objfn == "pMI") {
         if (abs(oldpMI) > sig) {
           break
@@ -344,6 +393,13 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
         } else {
           break
         }
+      } else if (objfn %in% c("AIC", "AICc", "BIC")) {
+        if (ref < IC) {
+          IC <- ref
+          sel_id <- c(sel_id, sid)
+        } else {
+          break
+        }
       } else if (objfn == "p") {
         if (ref < sig) {
           sel_id <- c(sel_id, sid)
@@ -393,8 +449,13 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   # fit & spatial autocorrelation
   fitvals <- fittedval(x = xev, params = coefs, model = "linear")
   resid <- residfun(y = y, fitvals = fitvals, model = "linear")$raw
-  R2 <- 1 - (sum(crossprod(resid)) / TSS)
+  RSS <- sum(crossprod(resid))
+  R2 <- 1 - (RSS / TSS)
   adjR2 <- 1 - (1 - R2) * (n - 1) / (n - ncol(xev))
+
+  negll <- 0.5 * n * (log(2 * pi) + 1 + log(RSS / n))
+  ICs <- getICs(negloglik = negll, n = n, df = length(coefs))
+
   MI_filtered <- MI.resid(resid = resid, x = xev, W = W, boot = boot.MI,
                           alternative = ifelse(dep == "positive", "greater", "lower"))
   MI_init <- MI.resid(resid = resid_init, x = x, W = W, boot = boot.MI,
@@ -404,9 +465,29 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   # Output
   #####
   # OLS estimates (filtered)
-  est <- cbind(coefs[1:nx], se[1:nx], p.val[1:nx])
-  colnames(est) <- c("Estimate", "SE", "p-value")
-  varcovar <- vcov[1:nx, 1:nx]
+  if (conditional.se) {
+    # partial regression to residualize y & x
+    if (count == 0) {
+      ME <- diag(n)
+    } else {
+      ME <- diag(n) - evecs[, sel_id] %*% solve(t(evecs[, sel_id]) %*% evecs[, sel_id]) %*% t(evecs[, sel_id])
+    }
+    MEy <- ME %*% y
+    MEx <- ME %*% x
+    resid <- MEy - MEx %*% coefs[1:nx]
+    # vcov, SEs & pvals
+    varcovar <- sum(resid^2) / (n - nx) * solve(t(MEx) %*% MEx)
+    betas_se <- sqrt(diag(varcovar))
+    betas_p <- 2 * pt(abs(coefs[1:nx] / betas_se), df = (n - nx), lower.tail = FALSE)
+    
+    est <- cbind(coefs[1:nx], betas_se, betas_p)
+    colnames(est) <- c("Estimate", "SE", "p-value")
+  } else {
+    est <- cbind(coefs[1:nx], se[1:nx], p.val[1:nx])
+    colnames(est) <- c("Estimate", "SE", "p-value")
+    varcovar <- vcov[1:nx, 1:nx]
+  }
+
   if (nx == 1) {
     rownames(est) <- names(varcovar) <- "(Intercept)"
   } else {
@@ -447,6 +528,8 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
   # model fit
   fit <- c(adjR2_init, adjR2)
   names(fit) <- c("Initial", "Filtered")
+  IC <- rbind(ICs_init, ICs)
+  rownames(IC) <- c("Initial", "Filtered")
 
   # residuals
   residuals <- cbind(resid_init, resid)
@@ -460,6 +543,7 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
                    evMI = evMI,
                    moran = moran,
                    fit = fit,
+                   ICs = IC,
                    residuals = residuals,
                    other = list(ncandidates = ncandidates,
                                 nev = count,
@@ -470,6 +554,7 @@ lmFilter <- function(y, x = NULL, W, objfn = "MI", MX = NULL, sig = .05,
                                 dependence = dep,
                                 objfn = objfn,
                                 bonferroni = bonferroni,
+                                conditional.se = conditional.se,
                                 siglevel = sig
                    )
   )
