@@ -75,7 +75,9 @@ residfun <- function(y, fitvals, size = NULL, model) {
     deviance <- sign * sqrt(2 * (y * log(ratio) - (y - fitvals)))
   } else if (model == "nb") {
     pearson <- (y - fitvals) / sqrt((fitvals + (fitvals^2 / size)))
-    deviance <- Inf
+    y_safe <- ifelse(y == 0, 1e-12, y) # avoids log(0)
+    devi <- 2 * (y_safe * log((y_safe * (size + fitvals)) / (fitvals * (size + y_safe)) ) + size * log( (size + fitvals) / (size + y_safe) ))
+    deviance <- sign(y - fitvals) * sqrt(devi)
   } else if (model == "linear") {
     pearson <- deviance <- raw
   }
@@ -130,8 +132,9 @@ conditionNumber <- function(evecs = NULL, round = 8) {
 
 getICs <- function(negloglik, n, df) {
   AIC <- 2 * negloglik + 2 * df
+  AICc <- AIC + (2 * df * (df + 1)) / (n - df - 1)
   BIC <- 2 * negloglik + log(n) * df
-  out <- data.frame(AIC, BIC)
+  out <- data.frame(AIC, AICc, BIC)
   return(out)
 }
 
@@ -157,3 +160,55 @@ Zscore <- function(x, na.rm = TRUE) {
   Z <- apply(x, 2, function(v) (v - mean(v, na.rm = na.rm)) / sd(v, na.rm = na.rm))
   return(Z)
 }
+
+
+#' @name soft_thresholding
+#' @noRd
+
+soft_thresholding <- function(z_cor, penalty_parameter) {
+  out <- sign(z_cor) * pmax(abs(z_cor) - penalty_parameter, 0)
+  return(out)
+}
+
+
+#' @name MI_lasso
+#' @noRd
+
+MI_lasso <- function(y, x, evecs, selset, zMI, n, maxit = 1000, tol = 1e-7) {
+  # regularization parameter
+  theta <- 1 / zMI^2 # suggested by Barde et al. (2025)
+
+  # coefficients
+  beta <- solve(crossprod(x), crossprod(x, y))
+  gamma <- rep(0, length(selset))
+  
+  # residuals
+  r <- y - x %*% beta - evecs[, selset, drop = FALSE] %*% gamma
+  
+  for (iter in seq_len(maxit)) {
+    beta_old <- beta
+    gamma_old <- gamma
+    
+    # update beta (unpenalized OLS step) & residuals
+    beta <- solve(crossprod(x), crossprod(x, y - evecs[, selset, drop = FALSE] %*% gamma))
+    r <- y - x %*% beta - evecs[, selset, drop = FALSE] %*% gamma
+    
+    # Update gamma (coordinate descent)
+    for (j in seq_along(selset)) {
+      sid <- selset[j]
+      r_j <- r + evecs[, sid] * gamma[j] # partial residual
+      z_j <- crossprod(evecs[, sid], r_j) # raw correlation / projection
+      gamma[j] <- soft_thresholding(z_j, theta)
+      r <- r_j - evecs[, sid] * gamma[j] # update residual
+    }
+    
+    # convergence check
+    if (max(abs(beta - beta_old)) < tol &&
+        max(abs(gamma - gamma_old)) < tol)
+      break
+  }
+  
+  sel_id <- selset[abs(gamma) > 1e-7]
+
+  return(sel_id)
+}
